.. _polys-literature:

==========
Literature
==========

The following is a non-comprehensive list of publications that were used as
a theoretical foundation for implementing polynomials manipulation module.

.. [Kozen89] D. Kozen, S. Landau, Polynomial decomposition algorithms,
    Journal of Symbolic Computation 7 (1989), pp. 445-456

.. [Liao95] Hsin-Chao Liao,  R. Fateman, Evaluation of the heuristic
    polynomial GCD, International Symposium on Symbolic and Algebraic
    Computation (ISSAC), ACM Press, Montreal, Quebec, Canada, 1995,
    pp. 240--247

.. [Gathen99] J. von zur Gathen, J. Gerhard, Modern Computer Algebra,
    First Edition, Cambridge University Press, 1999

.. [Weisstein09] Eric W. Weisstein, Cyclotomic Polynomial, From MathWorld - A
    Wolfram Web Resource, http://mathworld.wolfram.com/CyclotomicPolynomial.html

.. [Wang78] P. S. Wang, An Improved Multivariate Polynomial Factoring
    Algorithm, Math. of Computation 32, 1978, pp. 1215--1231

.. [Geddes92] K. Geddes, S. R. Czapor, G. Labahn, Algorithms for
    Computer Algebra, Springer, 1992

.. [Monagan93] Michael Monagan, In-place Arithmetic for Polynomials
    over Z_n, Proceedings of DISCO '92, Springer-Verlag LNCS, 721,
    1993, pp. 22--34

.. [Kaltofen98] E. Kaltofen, V. Shoup, Subquadratic-time Factoring of
    Polynomials over Finite Fields, Mathematics of Computation, Volume
    67, Issue 223, 1998, pp. 1179--1197

.. [Shoup95] V. Shoup, A New Polynomial Factorization Algorithm and
    its Implementation, Journal of Symbolic Computation, Volume 20,
    Issue 4, 1995, pp. 363--397

.. [Gathen92] J. von zur Gathen, V. Shoup, Computing Frobenius Maps
    and Factoring Polynomials, ACM Symposium on Theory of Computing,
    1992, pp. 187--224

.. [Shoup91] V. Shoup, A Fast Deterministic Algorithm for Factoring
    Polynomials over Finite Fields of Small Characteristic, In Proceedings
    of International Symposium on Symbolic and Algebraic Computation, 1991,
    pp. 14--21

.. [Cox97] D. Cox, J. Little, D. O'Shea, Ideals, Varieties and
    Algorithms, Springer, Second Edition, 1997

.. [Ajwa95] I.A. Ajwa, Z. Liu, P.S. Wang, Gröbner Bases Algorithm, 1995

.. [Bose03] N.K. Bose, B. Buchberger, J.P. Guiver, Multidimensional
    Systems Theory and Applications, Springer, 2003

.. [Giovini91] A. Giovini, T. Mora, "One sugar cube, please" or
    Selection strategies in Buchberger algorithm, ISSAC '91, ACM

.. [Bronstein93] M. Bronstein, B. Salvy, Full partial fraction
    decomposition of rational functions, Proceedings ISSAC '93,
    ACM Press, Kiev, Ukraine, 1993, pp. 157--160

.. [Buchberger01] B. Buchberger, Gröbner Bases: A Short Introduction for
    Systems Theorists,  In: R. Moreno-Diaz,  B. Buchberger,
    J. L. Freire, Proceedings of EUROCAST'01, February, 2001

.. [Davenport88] J.H. Davenport, Y. Siret, E. Tournier, Computer Algebra
    Systems and Algorithms for Algebraic Computation, Academic Press, London,
    1988, pp. 124--128

.. [Collins67] G.E. Collins, Subresultants and Reduced Polynomial
   Remainder Sequences. J. ACM 14 (1967) 128-142

.. [BrownTraub71] W.S. Brown, J.F. Traub, On Euclid's Algorithm and
   the Theory of Subresultants. J. ACM 18 (1971) 505-514

.. [Brown78] W.S. Brown, The Subresultant PRS Algorithm.
   ACM Transaction of Mathematical Software 4 (1978) 237-249

.. [Monagan00] M. Monagan and A. Wittkopf, On the Design and Implementation
    of Brown’s Algorithm over the Integers and Number Fields, Proceedings of
    ISSAC 2000, pp. 225-233, ACM, 2000.

.. [Brown71] W.S. Brown, On Euclid's Algorithm and the Computation of
    Polynomial Greatest Common Divisors, J. ACM 18, 4, pp. 478-504, 1971.

.. [Hoeij04] M. van Hoeij and M. Monagan, Algorithms for polynomial GCD
    computation over algebraic function fields, Proceedings of ISSAC 2004,
    pp. 297-304, ACM, 2004.

.. [Wang81] P.S. Wang, A p-adic algorithm for univariate partial fractions,
    Proceedings of SYMSAC 1981, pp. 212-217, ACM, 1981.

.. [Hoeij02] M. van Hoeij and M. Monagan, A modular GCD algorithm over
    number fields presented with multiple extensions, Proceedings of ISSAC
    2002, pp. 109-116, ACM, 2002

.. [ManWright94] Yiu-Kwong Man and Francis J. Wright, "Fast Polynomial Dispersion
    Computation and its Application to Indefinite Summation",
    Proceedings of the International Symposium on Symbolic and
    Algebraic Computation, 1994, Pages 175-180
    https://dl.acm.org/citation.cfm?doid=190347.190413

.. [Koepf98] Wolfram Koepf, "Hypergeometric Summation: An Algorithmic Approach
    to Summation and Special Function Identities", Advanced lectures
    in mathematics, Vieweg, 1998

.. [Abramov71] S. A. Abramov, "On the Summation of Rational Functions",
    USSR Computational Mathematics and Mathematical Physics,
    Volume 11, Issue 4, 1971, Pages 324-330

.. [Man93] Yiu-Kwong Man, "On Computing Closed Forms for Indefinite Summations",
    Journal of Symbolic Computation, Volume 16, Issue 4, 1993, Pages 355-376
    http://www.sciencedirect.com/science/article/pii/S0747717183710539

.. [BenOr81] M. Ben-Or, Probabilistic algorithms in finite fields.  In
    Proc. 22nd IEEE Symp. FoundationsComputer Science (1981), pp. 394-398.

.. [Adams94] W. Adams and P. Loustaunau, An Introduction to Gröbner Bases.
    AMS, Providence, Rhode Island., pp. 97-101, 1994.

.. [BeckerWeispfenning93] Thomas Becker, Volker Weispfenning, Gröbner
    bases: A computational approach to commutative algebra, 1993.
